Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(216)

Unified Diff: ios/web/public/test/fakes/test_navigation_manager.h

Issue 2766063002: Remove the concept of currentItemIndex (Closed)
Patch Set: fix unit tests Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ios/web/public/navigation_manager.h ('k') | ios/web/public/test/fakes/test_navigation_manager.mm » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ios/web/public/test/fakes/test_navigation_manager.h
diff --git a/ios/web/public/test/fakes/test_navigation_manager.h b/ios/web/public/test/fakes/test_navigation_manager.h
index 53a7ef0aac4f2fafb6e2665aa3870a031487bb10..4f8be46c383ca90a1278eba853bd775091881a43 100644
--- a/ios/web/public/test/fakes/test_navigation_manager.h
+++ b/ios/web/public/test/fakes/test_navigation_manager.h
@@ -31,7 +31,6 @@ class TestNavigationManager : public NavigationManager {
BrowserURLRewriter::URLRewriter rewriter) override;
int GetItemCount() const override;
NavigationItem* GetItemAtIndex(size_t index) const override;
- int GetCurrentItemIndex() const override;
int GetPendingItemIndex() const override;
int GetLastCommittedItemIndex() const override;
bool RemoveItemAtIndex(int index) override;
@@ -63,9 +62,9 @@ class TestNavigationManager : public NavigationManager {
// GetItemAtIndex(), and GetCurrentItemIndex().
void AddItem(const GURL& url, ui::PageTransition transition);
- // Sets the index to be returned by GetCurrentItemIndex(). |index| must be
- // either -1 or between 0 and GetItemCount()-1, inclusively.
- void SetCurrentItemIndex(const int index);
+ // Sets the index to be returned by GetLastCommittedItemIndex(). |index| must
+ // be either -1 or between 0 and GetItemCount()-1, inclusively.
+ void SetLastCommittedItemIndex(const int index);
private:
// A list of items constructed by calling AddItem().
« no previous file with comments | « ios/web/public/navigation_manager.h ('k') | ios/web/public/test/fakes/test_navigation_manager.mm » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698